-- CONFIG
local vmm = {}
vmm.scale     = 1.20   -- Set frame scale
vmm.position  = true   -- Set frame position
vmm.coord     = { "TOPRIGHT", "UIParent", "TOPRIGHT", -8, -18 }  -- Set frame location
vmm.map       = true   -- Hide world map button
vmm.gtt       = true   -- Hide game time texture
vmm.mmb       = false  -- Hide minimap border top, zone text and toggle button
vmm.track     = true   -- Hide tracking frame
vmm.zoom      = true   -- Hide zoom in/out buttons
vmm.mouse     = true   -- Mouse wheel zoom
vmm.dark      = true   -- Make frames darker
vmm.frameRgb  = { 0.5, 0.5, 0.5, 1 }  -- Set frame darkness

-- SCALE
MinimapCluster:SetScale(vmm.scale)

-- POSITION
if vmm.position then
    local function ApplyPosition()

        MinimapCluster:ClearAllPoints()
        MinimapCluster:SetPoint(unpack(vmm.coord))
        PlayerFrame:SetUserPlaced(true)

    end

    local enteringWorld = CreateFrame("Frame")
    enteringWorld:RegisterEvent("PLAYER_ENTERING_WORLD")
    enteringWorld:SetScript("OnEvent", ApplyPosition)
end

-- HIDE STUFF
if vmm.map then
 MiniMapWorldMapButton:Hide()
end

if vmm.gtt then
 GameTimeTexture:Hide()
end

if vmm.mmb then
 MinimapBorderTop:Hide()
 MinimapZoneText:Hide()
 MinimapToggleButton:Hide()
end

if vmm.track then
 MiniMapTrackingBorder:Hide()
 MiniMapTrackingIcon:Hide()
end

if vmm.zoom then
 MinimapZoomOut:Hide()
 MinimapZoomIn:Hide()
end

-- MOUSE WHEEL ZOOM
if vmm.mouse then
    local CF=CreateFrame("Frame")
    	CF:RegisterEvent("PLAYER_ENTERING_WORLD")
    	CF:SetScript("OnEvent", function(self, event) 
    		Minimap:EnableMouseWheel(true)
    		Minimap:SetScript("OnMouseWheel", function(self, z)
    			local c = Minimap:GetZoom()
    			if(z > 0 and c < 5) then
    				Minimap:SetZoom(c + 1)
    			elseif(z < 0 and c > 0) then
    				Minimap:SetZoom(c - 1)
    			end
    		end)
	end)
end

-- DARK FRAMES
if vmm.dark then
    for _, v in next, {
        MinimapBorder,
        MinimapBorderTop,
        MiniMapLFGFrameBorder,
        MiniMapMailBorder,
        MiniMapTrackingButtonBorder,
        MiniMapBattlefieldBorder,
        QueueStatusMinimapButtonBorder,
        MiniMapTrackingBorder,
    }
    do
        v:SetVertexColor(unpack(vmm.frameRgb))
    end
end
